==> ovirt-hosted-engine-setup-2.0.1.3.tar.gz: ovirt-hosted-engine-setup-2.0.1.3/src/plugins/gr-he-setup/network/firewall.py <==
#
# ovirt-hosted-engine-setup -- ovirt hosted engine setup
# Copyright (C) 2013-2015 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#


"""
Firewall configuration plugin for Hosted Engine.
"""

import gettext


from otopi import plugin
from otopi import util


from ovirt_hosted_engine_setup import constants as ohostedcons


def _(m):
    return gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')


@util.export
class Plugin(plugin.PluginBase):
    """
    Firewall configuration plugin for Hosted Engine
    """

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_CUSTOMIZATION,
        after=(
            ohostedcons.Stages.DIALOG_TITLES_S_NETWORK,
            ohostedcons.Stages.NET_FIREWALL_MANAGER_AVAILABLE,
        ),
        before=(
            ohostedcons.Stages.DIALOG_TITLES_E_NETWORK,
            ohostedcons.Stages.NET_FIREWALL_MANAGER_PROCESS_TEMPLATES,
        ),
        condition=lambda self: not self.environment[
            ohostedcons.CoreEnv.IS_ADDITIONAL_HOST
        ],
    )
    def _configuration(self):
        self.environment[ohostedcons.NetworkEnv.FIREWALLD_SERVICES].extend([
            {
                'name': 'hosted-console',
                'directory': 'base'
            },
            {
                'name': 'hosted-cockpit',
                'directory': 'base'
            },
        ])


# vim: expandtab tabstop=4 shiftwidth=4

==> ovirt-hosted-engine-setup-2.1.1.tar.gz: ovirt-hosted-engine-setup-2.1.1/src/plugins/gr-he-setup/network/firewall.py <==
#
# ovirt-hosted-engine-setup -- ovirt hosted engine setup
# Copyright (C) 2013-2015 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#


"""
Firewall configuration plugin for Hosted Engine.
"""

import gettext

from otopi import plugin
from otopi import util

from ovirt_hosted_engine_setup import constants as ohostedcons


def _(m):
    return gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')


@util.export
class Plugin(plugin.PluginBase):
    """
    Firewall configuration plugin for Hosted Engine
    """

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_CUSTOMIZATION,
        after=(
            ohostedcons.Stages.DIALOG_TITLES_S_NETWORK,
            ohostedcons.Stages.NET_FIREWALL_MANAGER_AVAILABLE,
        ),
        before=(
            ohostedcons.Stages.DIALOG_TITLES_E_NETWORK,
            ohostedcons.Stages.NET_FIREWALL_MANAGER_PROCESS_TEMPLATES,
        ),
    )
    def _configuration(self):
        self.environment[ohostedcons.NetworkEnv.FIREWALLD_SERVICES].extend([
            {
                'name': 'hosted-console',
                'directory': 'base'
            },
            {
                'name': 'hosted-cockpit',
                'directory': 'base'
            },
        ])
        if self.environment[ohostedcons.StorageEnv.ENABLE_HC_GLUSTER_SERVICE]:
            self.environment[
                ohostedcons.NetworkEnv.FIREWALLD_SERVICES
            ].extend([
                {
                    'name': 'hosted-gluster',
                    'directory': 'base'
                },
            ])


# vim: expandtab tabstop=4 shiftwidth=4
